<!-- 新增编辑弹窗 -->
<template>
    <j-modal
        v-if="visible"
        :title="props.title"
        :maskClosable="false"
        destroy-on-close
        visible
        @ok="submitData"
        @cancel="close"
        okText="确定"
        cancelText="取消"
    >
        <j-form
            layout="vertical"
            ref="formRef"
            :rules="rules"
            :model="formModel"
        >
            <j-form-item label="省份" name="province">
                <j-select
                    style="width: 100%"
                    v-model:value="formModel.province"
                    placeholder="请选省份"
                    allowClear
                    @select="onSelectProvince"
                >
                    <j-select-option
                        v-for="item in provinceOption"
                        :key="item.id"
                        :value="item.id"
                        >{{ item.name }}</j-select-option
                    >
                </j-select>
            </j-form-item>
            <j-form-item label="城市" name="city">
                <j-select
                    style="width: 100%"
                    v-model:value="formModel.city"
                    placeholder="请选择城市"
                    allowClear
                    @select="onSelectCity"
                >
                    <j-select-option
                        v-for="item in cityOption"
                        :key="item.id"
                        :value="item.id"
                        >{{ item.name }}</j-select-option
                    >
                </j-select>
            </j-form-item>
            <j-form-item label="区域" name="region">
                <j-select
                    style="width: 100%"
                    v-model:value="formModel.region"
                    placeholder="请选择区域"
                    allowClear
                >
                    <j-select-option
                        v-for="item in regionOption"
                        :key="item.id"
                        :value="item.id"
                        >{{ item.name }}</j-select-option
                    >
                </j-select>
            </j-form-item>
            <j-form-item label="单位名称" name="name">
                <j-input
                    v-model:value="formModel.name"
                    :maxlength="64"
                    placeholder="请输入单位名称"
                />
            </j-form-item>
        </j-form>
    </j-modal>
</template>
<script setup lang="ts" name="modifyModal">
import { PropType } from 'vue';
import { Form, message } from 'jetlinks-ui-components';
// import { queryTree, saveTree, updateTree } from '@/api/device/category';
import {
    updateTree,
    saveInstitution
} from '@/api/warehouse/institution';
import { queryRegion } from '@/api/warehouse/region';

const emits = defineEmits(['refresh']);
const formRef = ref();
const useForm = Form.useForm;
const props = defineProps({
    formData: {
        type: Object as PropType<Record<string, any>>,
        default: () => {},
    },
    title: {
        type: String,
        defult: '',
    },
    isAdd: {
        type: Number,
        default: 0,
    },
    isChild: {
        type: Number,
        default: 0,
    },
});
interface formState {
    id?: string;
    name: string;
    city: string;
    region: string;
    province: string;
}
const listData = ref([]);
const childArr = ref([]);
const arr = ref([]);
const updateObj = ref({});
const addObj = ref({});
const addParams = ref({});
const provinceOption = ref<any>([]);
const cityOption = ref<any>([]);
const regionOption = ref<any>([]);

onMounted(() => {
    queryRegionHandle();
});

// 查询区域树数据
const queryRegionHandle = async () => {
    let params = {
        pageIndex: 0,
        pageSize: 12,
        paging: false,
        sorts: [
            { name: 'sortIndex', order: 'asc' },
            { name: 'createTime', order: 'desc' },
        ],
        terms: [],
    };
    let res: any = await queryRegion(params);
    provinceOption.value = res.result;
};

// 选择省份回调
const onSelectProvince = (value: string, option: any) => {
    console.log('onSelectProvince:', value, option);
    provinceOption.value.map((item: any) => {
        if (item.id == value) {
            cityOption.value = item.children;
        }
    });
};

// 选择城市回调
const onSelectCity = (value: string, option: any) => {
    console.log('onSelectCity:', value, option);
    cityOption.value.map((item: any) => {
        if (item.id == value) {
            regionOption.value = item.children;
        }
    });
};

/**
 * 表单数据
 */
const formModel = ref<formState>({
    name: '',
    city: '',
    region: '',
    province: '',
});
const rules = ref({
    name: [
        { required: true, message: '请输入单位名称', trigger: 'blur' },
        {
            max: 64,
            message: '最多可输入64个字符',
        },
    ],
    province: [{ required: true, message: '请选择省份', trigger: 'change' }],
    city: [{ required: true, message: '请选择城市', trigger: 'change' }],
    region: [{ required: true, message: '请选择区域', trigger: 'change' }],
});
const visible = ref(false);
const { resetFields, validate, validateInfos } = useForm(
    formModel.value,
    rules.value,
);
/**
 * 提交数据
 */
const submitData = async () => {
    formRef.value.validate().then(async () => {
        addParams.value = {};
        console.log("submitData:", formModel.value);
        if (props.isAdd === 0) {
            addParams.value = {
                provinceId: formModel.value.province,
                cityId: formModel.value.city,
                regionId: formModel.value.region,
                name: formModel.value.name
            };
            const res = await saveInstitution(addParams.value);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        } else if (props.isAdd === 2) {
            const id = formModel.value.id || "";
            const updateParams = {
                ...formModel.value
            };
            const res = await updateTree(id, updateParams);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        }
    });
};

/**
 * 显示弹窗
 */
const show = async (row: any) => {
    //新增
    if (props.isAdd === 0) {
        formModel.value = {
            province: "",
            city: "",
            region: "",
            name: ""
        };
        visible.value = true;
    } else if (props.isAdd === 2) {
        updateObj.value = row;
        // 编辑
        formModel.value = {
            id: row.id,
            province: row.province.name,
            city: row.city.name,
            region: row.region.name,
            name: row.name
        };
        visible.value = true;
    }
};
/**
 * 关闭弹窗
 */
const close = () => {
    visible.value = false;
    resetFields();
};
//监听项目ID
watch([() => props.isAdd], () => {}, { immediate: false, deep: true });
defineExpose({
    show: show,
});
</script>
<style></style>
